summaryrefslogtreecommitdiff
path: root/sw/source/uibase/inc/navmgr.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'sw/source/uibase/inc/navmgr.hxx')
-rw-r--r--sw/source/uibase/inc/navmgr.hxx4
1 files changed, 2 insertions, 2 deletions
diff --git a/sw/source/uibase/inc/navmgr.hxx b/sw/source/uibase/inc/navmgr.hxx
index d462cf0a7736..96288ba467db 100644
--- a/sw/source/uibase/inc/navmgr.hxx
+++ b/sw/source/uibase/inc/navmgr.hxx
@@ -19,14 +19,14 @@
class SwWrtShell;
struct SwPosition;
-class SwUnoCrsr;
+class SwUnoCursor;
class SwNavigationMgr
{
private:
/*
* List of entries in the navigation history
* Entries are SwUnoCrsr because these gets corrected automatically
* when nodes are deleted.
*
* The navigation history behaves as a stack, to which items are added when we jump to a new position
@@ -19,14 +19,14 @@
/*
* List of entries in the navigation history
- * Entries are SwUnoCrsr because these gets corrected automatically
+ * Entries are SwUnoCursor because these gets corrected automatically
* when nodes are deleted.
*